@@ -4,56 +4,62 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 #----------------------------------------------------------------------------
 
 my %map = (
     # Unix (and like) family OSes
-    'freebsd'   => 'BSD',
-    'openbsd'   => 'BSD',
-    'netbsd'    => 'BSD',
-    'irix'      => 'Irix',
-    'linux'     => 'Linux',
-    'aix'       => 'Linux',
-    'bsdos'     => 'Linux',
-    'dgux'      => 'Linux',
-    'dynixptx'  => 'Linux',
-    'hpux'      => 'Linux',
-    'dec_osf'   => 'Linux',
-    'svr4'      => 'Linux',
-    'unicos'    => 'Linux',
-    'unicosmk'  => 'Linux',
-    'sunos'     => 'Linux',
-    'ultrix'    => 'Linux',
-    'sco_sv'    => 'SCO',
-    'sco3'      => 'SCO',
-    'sco'       => 'SCO',
-    'solaris'   => 'Solaris',
+    'freebsd'       => 'BSD',
+    'openbsd'       => 'BSD',
+    'netbsd'        => 'BSD',
+    'mirbsd'        => 'BSD',
+    'dragonfly'     => 'BSD',
+    'midnightbsd'   => 'BSD',
+    
+    'irix'          => 'Irix',
+    
+    'linux'         => 'Linux',
+    'aix'           => 'Linux',
+    'bsdos'         => 'Linux',
+    'dgux'          => 'Linux',
+    'dynixptx'      => 'Linux',
+    'hpux'          => 'Linux',
+    'dec_osf'       => 'Linux',
+    'svr4'          => 'Linux',
+    'unicos'        => 'Linux',
+    'unicosmk'      => 'Linux',
+    'ultrix'        => 'Linux',
+    
+    'sco_sv'        => 'SCO',
+    'sco3'          => 'SCO',
+    'sco'           => 'SCO',
+
+    'solaris'       => 'Solaris',
+    'sunos'         => 'Solaris',
 
     # Windows family OSes
-    'dos'       => 'Win32',
-    'os2'       => 'Win32',
-    'mswin32'   => 'Win32',
-    'netware'   => 'Win32',
-    'cygwin'    => 'Win32',
+    'dos'           => 'Win32',
+    'os2'           => 'Win32',
+    'mswin32'       => 'Win32',
+    'netware'       => 'Win32',
+    'cygwin'        => 'Win32',
 
     # Mac family OSes
-    'macos'     => 'Mac',
-    'rhapsody'  => 'Mac',
-    'darwin'    => 'Mac',
+    'macos'         => 'Mac',
+    'rhapsody'      => 'Mac',
+    'darwin'        => 'Mac',
 
     # Other OSes
-    'vms'       => 'Linux',
-    'vos'       => 'Linux',
-    'os390'     => 'Linux',
-    'vmesa'     => 'Linux',
-    'riscos'    => 'Linux',
-    'amigaos'   => 'Linux',
-    'beos'      => 'Linux',
-    'machten'   => 'Linux',
-    'mpeix'     => 'Linux',
-
+    'vms'           => 'Linux',
+    'vos'           => 'Linux',
+    'os390'         => 'Linux',
+    'vmesa'         => 'Linux',
+    'riscos'        => 'Linux',
+    'amigaos'       => 'Linux',
+    'beos'          => 'Linux',
+    'machten'       => 'Linux',
+    'mpeix'         => 'Linux',
 );
 
 #----------------------------------------------------------------------------
@@ -174,7 +180,7 @@ RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010-2011 Birmingham Perl Mongers
+  Copyright (C) 2010-2012 Birmingham Perl Mongers
 
   This module is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
