@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 #----------------------------------------------------------------------------
 
@@ -36,7 +36,7 @@ sub get_info {
     for my $cmd (keys %commands) {
         $self->{cmds}{$cmd} = `$commands{$cmd} 2>/dev/null`;
         $self->{cmds}{$cmd} =~ s/\s+$//s;
-        $self->{info}{$cmd} = $self->{cmds}{$cmd}   if($cmd =~ /^[^_]/);
+        $self->{info}{$cmd} = $self->{cmds}{$cmd}   if($cmd !~ /^_/);
     }
 
     $self->{info}{osflag}   = $^O;
@@ -133,7 +133,7 @@ RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010-2011 Birmingham Perl Mongers
+  Copyright (C) 2010-2012 Birmingham Perl Mongers
 
   This module is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
